package sun.security.jgss;

import java.io.EOFException;
import java.io.InputStream;
import java.io.IOException;
import java.io.OutputStream;

public abstract class GSSToken
{
    public GSSToken() {
    }
    
    public static final void writeLittleEndian(int n, byte[] array) {
        writeLittleEndian(n, array, 0);
    }
    
    public static final void writeLittleEndian(int n, byte[] array, int n2) {
        array[n2++] = (byte)n;
        array[n2++] = (byte)(n >>> 8);
        array[n2++] = (byte)(n >>> 16);
        array[n2++] = (byte)(n >>> 24);
    }
    
    public static final void writeBigEndian(int n, byte[] array) {
        writeBigEndian(n, array, 0);
    }
    
    public static final void writeBigEndian(int n, byte[] array, int n2) {
        array[n2++] = (byte)(n >>> 24);
        array[n2++] = (byte)(n >>> 16);
        array[n2++] = (byte)(n >>> 8);
        array[n2++] = (byte)n;
    }
    
    public static final int readLittleEndian(byte[] array, int n, int i) {
        int n2 = 0;
        int n3 = 0;
        while (i > 0) {
            n2 += (array[n] & 0xFF) << n3;
            n3 += 8;
            ++n;
            --i;
        }
        return n2;
    }
    
    public static final int readBigEndian(byte[] array, int n, int i) {
        int n2 = 0;
        int n3 = (i - 1) * 8;
        while (i > 0) {
            n2 += (array[n] & 0xFF) << n3;
            n3 -= 8;
            ++n;
            --i;
        }
        return n2;
    }
    
    public static final void writeInt(int n, OutputStream outputStream) throws IOException {
        outputStream.write(n >>> 8);
        outputStream.write(n);
    }
    
    public static final int writeInt(int n, byte[] array, int n2) {
        array[n2++] = (byte)(n >>> 8);
        array[n2++] = (byte)n;
        return n2;
    }
    
    public static final int readInt(InputStream inputStream) throws IOException {
        return (0xFF & inputStream.read()) << 8 | (0xFF & inputStream.read());
    }
    
    public static final int readInt(byte[] array, int n) {
        return (0xFF & array[n]) << 8 | (0xFF & array[n + 1]);
    }
    
    public static final void readFully(InputStream inputStream, byte[] array) throws IOException {
        readFully(inputStream, array, 0, array.length);
    }
    
    public static final void readFully(InputStream inputStream, byte[] b, int off, int i) throws IOException {
        while (i > 0) {
            int read = inputStream.read(b, off, i);
            if (read == -1) {
                throw new EOFException("Cannot read all " + i + " bytes needed to form this token!");
            }
            off += read;
            i -= read;
        }
    }
    
    public static final void debug(String s) {
        System.err.print(s);
    }
    
    public static final String getHexBytes(byte[] array) {
        return getHexBytes(array, 0, array.length);
    }
    
    public static final String getHexBytes(byte[] array, int n) {
        return getHexBytes(array, 0, n);
    }
    
    public static final String getHexBytes(byte[] array, int i, int n) {
        StringBuffer sb = new StringBuffer();
        int j;
        int k;
        for (; i < i + n; ++i) {
            j = (array[i] >> 4 & 0xF);
            k = (array[i] & 0xF);
            sb.append(Integer.toHexString(j));
            sb.append(Integer.toHexString(k));
            sb.append(' ');
        }
        return sb.toString();
    }
}
